@@ -1,9 +1,12 @@
 import logging
 import threading
-from typing import List, Dict, Optional
+from typing import List, Dict, Optional, TYPE_CHECKING
 
 from openmodule.models.alert import AlertHandleType, AlertMessage, AlertStatus
 
+if TYPE_CHECKING:
+    from openmodule.core import OpenModuleCore
+
 
 class AlertHandler(object):
     _alerts: List[Dict]
@@ -38,9 +41,9 @@ class AlertHandler(object):
             return True
         return False
 
-    def get_or_add_alert_id(self, source: str, alert_type: str, handle_type: AlertHandleType,
+    def get_or_add_alert_id(self, alert_type: str, handle_type: AlertHandleType, *,
                             package_name: Optional[str] = None, version: Optional[str] = None,
-                            always_send_alert: Optional[bool] = None):
+                            always_send_alert: Optional[bool] = None, source: str = ""):
         """Define an alert with its name parameters
 
         Args:
@@ -89,10 +92,10 @@ class AlertHandler(object):
 
         return self._send_message(alert_id, status_dict)
 
-    def send(self, source: str, alert_type: str, handle_type: AlertHandleType,
+    def send(self, alert_type: str, handle_type: AlertHandleType, *,
              package_name: Optional[str] = None, version: Optional[str] = None,
              always_send_alert: Optional[bool] = None, status: AlertStatus = AlertStatus.error,
-             meta: Optional[Dict] = None, value: Optional[float] = None):
+             meta: Optional[Dict] = None, value: Optional[float] = None, source: str = ""):
 
         """Sends an alert to the device serve
 
@@ -112,5 +115,6 @@ class AlertHandler(object):
         """
         assert "-" not in alert_type, "please do not use - in your alert type names"
 
-        alert_id = self.get_or_add_alert_id(source, alert_type, handle_type, package_name, version, always_send_alert)
+        alert_id = self.get_or_add_alert_id(alert_type, handle_type, package_name=package_name, version=version,
+                                            always_send_alert=always_send_alert, source=source)
         return self.send_with_alert_id(alert_id, status, meta, value)
