@@ -84,6 +84,11 @@ def debug():
     else:
         return version() == "unknown" and not _inside_docker()
 
+def bridged_slave():
+    if "BRIDGED_SLAVE" in os.environ:
+        return bool("BRIDGED_SLAVE", default=False)
+    else:
+        return None
 
 def settings_module():
     if testing() and os.path.exists("../tests/config.py"):
@@ -130,7 +135,7 @@ def resource() -> str:
 
 def broker_pub(default: str = "tcp://127.0.0.1:10200") -> str:
     broker_host = string("BROKER_HOST", "")
-    broker_pub_port = int("BROKER_PUB_PORT", 0)
+    broker_pub_port = int("BROKER_PUB_PORT", 10200)
     broker_pub = string("BROKER_PUB", "")
 
     if broker_pub:
@@ -144,7 +149,7 @@ def broker_pub(default: str = "tcp://127.0.0.1:10200") -> str:
 
 def broker_sub(default: str = "tcp://127.0.0.1:10100") -> str:
     broker_host = string("BROKER_HOST", "")
-    broker_sub_port = int("BROKER_SUB_PORT", 0)
+    broker_sub_port = int("BROKER_SUB_PORT", 10100)
     broker_sub = string("BROKER_SUB", "")
 
     if broker_sub:
@@ -199,7 +204,7 @@ def yaml(model: Type[YamlType], path: str = None) -> YamlType:
             import yaml
             with open(yaml_path, "r") as f:
                 a = yaml.load(f, SafeLoaderIgnoreUnknown)
-                return model.parse_obj(a)
+                return model.parse_obj(a or {})
         else:
             return model()
     except ValidationError as e:
@@ -383,7 +388,12 @@ class OverrideSettings:
                 if self.lazy_setting is not None:
                     if len(self.overrides[k]) == 1:
                         self.lazy_setting._wrapped._explicit_settings.remove(k)
-                    setattr(self.lazy_setting, k, self.overrides[k][-1])
+
+                    if len(self.overrides[k]) == 0:
+                        # deletes the attribute if it never existed in the base config in the first place
+                        delattr(self.lazy_setting, k)
+                    else:
+                        setattr(self.lazy_setting, k, self.overrides[k][-1])
 
     def set_base(self, lazy_setting, options):
         assert self.lazy_setting is None, "Do not use multiple settings"
@@ -442,6 +452,7 @@ class GlobalSettings:
     BROKER_PUB = broker_pub()
 
     LOCAL_DEVELOPMENT = bool("LOCAL_DEVELOPMENT", False)
+    BRIDGED_SLAVE = bridged_slave()
 
 
 settings = LazySettings()
