@@ -1,5 +1,8 @@
-from sqlalchemy import TypeDecorator, DateTime
+from datetime import datetime
+
+from sqlalchemy import DateTime
 from sqlalchemy.sql.visitors import VisitableType
+from sqlalchemy.types import TypeDecorator
 
 
 class MetaOptions(VisitableType):
@@ -35,5 +38,7 @@ class TZDateTime(CustomType):
 
     def process_bind_param(self, value, dialect):
         if value is not None:
-            assert value.tzinfo is None, "You need to convert a datetime to a naive time, because sqlite loses tz infos"
+            assert not isinstance(value, datetime) or value.tzinfo is None, (
+                "You need to convert a datetime to a naive time, because sqlite loses tz infos. "
+            )
         return value
