@@ -1,11 +1,10 @@
+import base64
+import binascii
 import re
-
-from json.encoder import ESCAPE_ASCII
-
-import json
-
 from datetime import datetime
+from decimal import Decimal
 from enum import Enum
+from json.encoder import ESCAPE_ASCII
 
 import orjson
 import zmq
@@ -48,6 +47,12 @@ def _unicode_escape(data):
     return ESCAPE_ASCII.sub(replace, data)
 
 
+def default(obj):
+    if isinstance(obj, Decimal):
+        return str(obj)
+    raise TypeError
+
+
 class OpenModuleModel(BaseModel, **meta_kwargs):
     class Config:
         validate_assignment = True
@@ -59,7 +64,7 @@ class OpenModuleModel(BaseModel, **meta_kwargs):
         data = self.dict()
         if self.__custom_root_type__:
             data = data[ROOT_KEY]
-        return _unicode_escape(orjson.dumps(data).decode()).encode("ascii")
+        return _unicode_escape(orjson.dumps(data, default=default).decode()).encode("ascii")
 
     def dict(self, **kwargs):
         kwargs.setdefault("by_alias", True)
@@ -82,6 +87,18 @@ def timezone_validator(field):
     return validator(field, allow_reuse=True)(_timezone_validator)
 
 
+def _base64_validator(cls, data, values, **kwargs):
+    try:
+        base64.b64decode(data)
+    except (binascii.Error, TypeError, ValueError):
+        raise ValueError("must be a bse64 string")
+    return data
+
+
+def base64_validator(field):
+    return validator(field, allow_reuse=True)(_base64_validator)
+
+
 _EPOCH_UTC = datetime(1970, 1, 1, tzinfo=UTC)
 _EPOCH_NAIVE = datetime(1970, 1, 1)
 
@@ -99,7 +116,7 @@ def datetime_to_timestamp(dt: datetime):
 
 
 class ZMQMessage(OpenModuleModel):
-    timestamp: datetime = Field(default_factory=lambda: datetime.now())
+    timestamp: datetime = Field(default_factory=lambda: datetime.utcnow())
     name: str
     type: str
 
