@@ -3,7 +3,7 @@ import os
 import time
 from multiprocessing import Process, Event
 from signal import SIGINT, SIGKILL
-from typing import Callable, Union, Type
+from typing import Callable, Union, Type, Optional
 from unittest import TestCase
 
 import multiprocessing_logging
@@ -33,9 +33,22 @@ class InterruptTestMixin(TestCase):
     for usage, look at file tests/test_interrupt
     """
 
+    process: Optional[ExceptionProcess] = None
+
+    def _kill_process(self):
+        # this is called in tear down and as a cleanup to make sure that under any circumstances the process is killed
+        # otherwise you have processes lingering around, potentially blocking ports which is quite annoying
+        if self.process and self.process.is_alive():
+            os.kill(self.process.pid, SIGKILL)
+
+    def setUp(self) -> None:
+        self.addCleanup(self._kill_process)
+        super().setUp()
+
     def tearDown(self):
         super().tearDown()
         Schema.to_file()
+        self._kill_process()
 
     def wait_for_setup(self):
         pass
@@ -53,17 +66,19 @@ class InterruptTestMixin(TestCase):
 
         multiprocessing_logging.uninstall_mp_handler(logger)
 
-    def signal_in_function(self, f: Callable, signal: Union[Type[KeyboardInterrupt], int], *,
-                           raise_exception_after: float = 3.0, shutdown_timeout: float = 3.0):
-        if signal == KeyboardInterrupt:
-            signal = SIGINT
+    def start_process(self, f: Callable):
+        """
+        starts the process and waits until it is responsive by calling calls wait_for_setup()
+        """
         multiprocessing_logging.install_mp_handler()
-        process = ExceptionProcess(target=f)
-        process.start()
-        self.wait_for_setup()
-        time.sleep(raise_exception_after)
-        self.assertFalse(process.is_finished.is_set())
-        os.kill(process.pid, signal)
+        self.process = ExceptionProcess(target=f)
+        self.process.start()
+        return self.process
+
+    def assertCleanShutdown(self, process, shutdown_timeout: float = 3.0):
+        """
+        asserts that the process shuts down cleanly
+        """
         if process.is_finished.wait(timeout=shutdown_timeout):
             self._wait_for_and_uninstall_mp_handler()
             return
@@ -74,6 +89,25 @@ class InterruptTestMixin(TestCase):
             else:
                 raise AssertionError("Process did not finish gracefully")
 
+    def send_signal_to_process(self, process: ExceptionProcess, signal: Union[Type[KeyboardInterrupt], int]):
+        self.assertFalse(process.is_finished.is_set())
+        if signal == KeyboardInterrupt:
+            signal = SIGINT
+        os.kill(process.pid, signal)
+
+    def signal_in_function(self, f: Callable, signal: Union[Type[KeyboardInterrupt], int], *,
+                           raise_exception_after: float = 3.0, shutdown_timeout: float = 3.0):
+        """
+        wraps the helper functions into a single function because apparently everybody likes
+        to write framework functions which are hard to adopt and do one single thing and nothing
+        else. mostly here for backwards compatibility and reference how to use the testcase
+        """
+        process = self.start_process(f)
+        self.wait_for_setup()
+        time.sleep(raise_exception_after)
+        self.send_signal_to_process(process, signal)
+        self.assertCleanShutdown(process, shutdown_timeout)
+
 
 class MainTestMixin(HealthTestMixin, InterruptTestMixin):
     topics = ["healthz"]
