@@ -1,3 +1,4 @@
+from datetime import datetime
 from functools import partial
 
 import orjson
@@ -7,9 +8,11 @@ import time
 from unittest import TestCase
 
 from openmodule.core import init_openmodule, shutdown_openmodule
-from openmodule.models.base import Direction
-from openmodule.models.presence import PresenceBaseMessage
-from openmodule.models.vehicle import MakeModel
+from openmodule.models.base import Direction, Gateway
+from openmodule.models.presence import PresenceBaseMessage, PresenceRPCRequest, PresenceRPCResponse, PresenceBaseData, \
+    PresenceMedia
+from openmodule.models.vehicle import MakeModel, LPRMedium, LPRCountry, PresenceAllIds
+from openmodule.rpc import RPCServer
 from openmodule.utils.presence import PresenceListener
 from openmodule_test.eventlistener import MockEvent
 from openmodule_test.presence import PresenceSimulator
@@ -55,7 +58,7 @@ class PresenceTest(BasePresenceTest):
         self.on_enter.wait_for_call()
         self.assertEqual("G ARIVO1", self.presence.present_vehicles["gate_in"].lpr.id)
 
-        MockEvent.reset_all_call_counts()
+        MockEvent.reset_all_mocks()
         self.presence_sim.current_present = None
         with self.assertLogs() as cm:
             self.presence_sim.enter(self.presence_sim.vehicle().lpr("A", "G ARIVO2"))
@@ -146,7 +149,7 @@ class PresenceTest(BasePresenceTest):
         vehicle_changed = vehicle.nfc("asdf")
         self.presence_sim.change(vehicle_changed)
         self.on_change.wait_for_call()
-        self.on_change.reset_call_count()
+        self.on_change.reset_mock()
 
 
 class PresenceTestUtilsTest(BasePresenceTest):
@@ -182,7 +185,7 @@ class GateFilterTest(BasePresenceTest):
         self.assertIn("gate_in", self.presence2.present_vehicles.keys())
         self.presence2.present_vehicles = {}
 
-        MockEvent.reset_all_call_counts()
+        MockEvent.reset_all_mocks()
 
         sim_out = PresenceSimulator("gate_out", Direction.OUT, lambda x: self.zmq_client.send(b"presence", x))
         sim_out.enter(sim_out.vehicle().lpr("A", "G ARIVO2"))
@@ -208,3 +211,51 @@ class PresenceSimulatorTest(TestCase):
         sim.forward()
         message = orjson.loads(self.message.json_bytes())
         self.assertIn("leave-time", message)
+
+
+class PresenceRPCTest(ZMQTestMixin, TestCase):
+    def setUp(self) -> None:
+        super().setUp()
+        self.core = init_openmodule(self.zmq_config(), context=self.zmq_context())
+        self.wait_for_dispatcher(self.core.messages)
+        self.presence_sim = PresenceSimulator("gate_in", Direction.IN, lambda x: self.zmq_client.send(b"presence", x))
+        self.rpc_server = RPCServer(context=self.core.context)
+        self.rpc_server.register_handler("tracking", "get-present", PresenceRPCRequest, PresenceRPCResponse,
+                                         self.on_reply)
+        self.rpc_server.run_as_thread()
+        self.present = False
+
+    def tearDown(self):
+        self.rpc_server.shutdown()
+        shutdown_openmodule()
+        super().tearDown()
+
+    def on_reply(self, request: PresenceRPCRequest, _) -> PresenceRPCResponse:
+        """
+        Emulates Trackings Presence RPC
+        """
+        if self.present:
+            return PresenceRPCResponse(presents=[
+                PresenceBaseData(vehicle_id=1, source="gate_in", present_area_name="gate_in",
+                                 last_update=datetime.utcnow(), gateway=Gateway(gate="gate_in", direction="in"),
+                                 medium=PresenceMedia(lpr=LPRMedium(id="T EST 1")), all_ids=PresenceAllIds())])
+        else:
+            return PresenceRPCResponse(presents=[])
+
+    def test_presence_rpc_plate(self):
+        self.present = True
+        self.presence = PresenceListener(self.core.messages, gate="gate_in")
+        self.presence.init_present_vehicles()
+        self.assertNotEqual({}, self.presence.present_vehicles)
+
+    def test_presence_rpc_no_plate(self):
+        self.present = False
+        self.presence = PresenceListener(self.core.messages, gate="gate_in")
+        self.presence.init_present_vehicles()
+        self.assertEqual({}, self.presence.present_vehicles)
+
+    def test_presence_rpc_only_allowed_for_gates(self):
+        self.presence = PresenceListener(self.core.messages)
+        with self.assertRaises(AssertionError) as e:
+            self.presence.init_present_vehicles()
+        self.assertIn("if the gate is set", str(e.exception))
